""" TEST SCRIPT for heeksremote
This script generates some 2D objects
and tests the operations
 - pocket
 - profile (inside, outside)
 - drilling
 
For profile cuts, tags can be added

To test, run script.
HeeksCAD starts and the objects are visible.
Menu - Machining - Post process
Menu View 

HeeksCAD must be installed!

"""

from heeksfunctions_012 import *


""" For all functions, the name argument is optional.
If not needed, it can be omitted."""
        
if __name__ == '__main__':
    
    set_feedrate(500,100)           # set_feedrate(xy, z)
    set_clearanceheight(15)
    
    # open new drawing:
    openheeks()
    
    # draw 2D objects with or without machining operation 
    
    point (0,10, "P01")
    drilling(3, 0, -6, 2)           # drilling(tool_number, startdepth, depth, stepdown)
    
    line(0,0,20,20, "diagonal")     # line(x1, y1, x2, y2, *name)
    # unfortunately this does not work:
    profile(1, ON_LINE, 0, -1, 1)  # profile(toolnumber, side, startdepth, depth, stepdown)
    
    circle(20,10,6, "test-c")       # circle(x,y,radius, *name)
    pocket(5, 0,-5,3,2)             # pocket(toolnumber, startdepth, depth, stepdown, stepover)
    
    
    rect(40,-10, 10, 25, "Plate")
    add_tag(0, 15)
    add_tag(30, 20)
    profile(2, INSIDE, 0, -3, 0.5)   # profile(toolnumber, side, startdepth, depth, stepdown)
    
    
    roundedrect(-30,-30, 25,15,5, "RoundedRect")
    add_tag(-20, -15)
    add_tag(-20, -30)
    profile(2, OUTSIDE, 0, -3, 1) 
    
    arc(30,30,30,20,30,30)          # arc(xcenter,ycenter, xbegin, ybegin, xend, yend )
    arc_ang(-20,0,20, +60, 90)     # arc_ang(xcenter, ycenter, r, alphabegin, alphaend)
    arc_e(-20, 0, 10, 2)            # arc_e(xcenter, ycenter, r, excentricity, *name)
    
    # helper functions for arc can be used to drill at extreme points and center:
    xb, yb, xe, ye = get_xy_begin_end()
    point(xb,yb)
    point(xe,ye) 
    x,y = get_center()  
    point(x,y)
    
    # It is easy to draw multiple objects with a for loop:
    for i in range(0,5):
        circle (i*10,-20,1.5)
        point (i*10,-20, "P"+str(i)) 
    
    # complex objects can consist of multiple lines
    opensketch("triangle")
    line (0,-5,30,-5)
    line(30,-5,30,5)
    line(30,5,0,-5)
    closesketch()
    pocket(1, 0,-5,3,2) 
        
    closeheeks()
    showheeks()
